package com.playlet.system.mapper;

import java.util.List;
import com.playlet.system.domain.PlayletPublicAccount;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 公众号列Mapper接口
 *
 * @author ruoyi
 * @date 2024-04-07
 */
public interface PlayletPublicAccountMapper extends BaseMapper<PlayletPublicAccount>
{
    /**
     * 查询公众号列
     *
     * @param id 公众号列主键
     * @return 公众号列
     */
    public PlayletPublicAccount selectPlayletPublicAccountById(Long id);

    /**
     * 查询公众号列列表
     *
     * @param playletPublicAccount 公众号列
     * @return 公众号列集合
     */
    public List<PlayletPublicAccount> selectPlayletPublicAccountList(PlayletPublicAccount playletPublicAccount);

    /**
     * 新增公众号列
     *
     * @param playletPublicAccount 公众号列
     * @return 结果
     */
    public int insertPlayletPublicAccount(PlayletPublicAccount playletPublicAccount);

    /**
     * 修改公众号列
     *
     * @param playletPublicAccount 公众号列
     * @return 结果
     */
    public int updatePlayletPublicAccount(PlayletPublicAccount playletPublicAccount);

    /**
     * 删除公众号列
     *
     * @param id 公众号列主键
     * @return 结果
     */
    public int deletePlayletPublicAccountById(Long id);

    /**
     * 批量删除公众号列
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletPublicAccountByIds(String[] ids);
}
